#
# spec file for package Collage
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define soname 2
Name:           Collage
Version:        1.1.2
Release:        5.1
Summary:        Object-Oriented C++ Network Library: Applications
License:        LGPL-2.1
Group:          Productivity/Networking/Other
Url:            http://www.equalizergraphics.com/
Source0:        https://github.com/Eyescale/Collage/archive/1.1.2.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/Eyescale/CMake/archive/master.tar.gz#/CMake-common_git20150515.tar.gz
# PATCH-FIX-UPSTREAM include.patch avvissu@yandex.ru -- Remove Buildyard project
Patch0:         Collage-1.1.2_include.patch
# PATCH-FIX-UPSTREAM boost-1.60.patch baggins@pld-linux.org -- Build with boost >= 1.60
Patch1:         Collage-1.1.2_boost-1.60.patch
# PATCH-FIX-UPSTREAM doxygen.patch avvissu@yandex.ru -- Fix build error: need administrative privileges
Patch2:         CMake_doxygen.patch
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  udt-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(Lunchbox)
BuildRequires:  pkgconfig(glew)
BuildRequires:  python-devel
%if 0%{?suse_version} > 1310
BuildRequires:  libibverbs-devel
BuildRequires:  librdmacm-devel
%endif

%description
Cross-platform C++ library for building heterogenous, distributed 
applications. Collage provides an abstraction of different network 
connections, peer-to-peer messaging, node discovery, synchronization and 
high-performance, object-oriented, versioned data distribution.

%package -n     lib%{name}%{soname}
Summary:        Object-Oriented C++ Network Library
License:        LGPL-2.1
Group:          System/Libraries

%description -n lib%{name}%{soname}
Cross-platform C++ library for building heterogenous, distributed 
applications. Collage provides an abstraction of different network 
connections, peer-to-peer messaging, node discovery, synchronization and 
high-performance, object-oriented, versioned data distribution.

%package        devel
Summary:        Development files for %{name}
License:        LGPL-2.1
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{soname} = %{version}
Requires:       boost-devel
Requires:       pkgconfig(Lunchbox)
Requires:       udt-devel

%description    devel
Object-Oriented C++ Network Library.
...
This package contains header files and libraries needed to develop
application that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
Object-Oriented C++ Network Library.
...
API Documentation for %{name}.

%prep
%setup -q -a1
mv CMake-common* CMake/common
%patch0 -p1
%if 0%{?suse_version} > 1320
%patch1 -p1
%endif
pushd CMake/common
%patch2 -p1
popd

# Do not compile in DATE and TIME
grep -rl 'HTML_TIMESTAMP' . | \
	xargs --no-run-if-empty --verbose \
	sed -i '/^HTML_TIMESTAMP/s/YES/NO/'

%build
%cmake \
	-DCMAKE_BUILD_TYPE=Release \
	-DCMAKE_SKIP_RPATH:BOOL=OFF

make %{?_smp_mflags}
make %{?_smp_mflags} doxygen

%install
%make_install -C build

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}{%{_datadir}/%{name}/doc,%{_docdir}/%{name}}

%fdupes -s %{buildroot}%{_docdir}

%check
# Only local test (Used network)
#sed -i '/ctest/s|\(bin/ctest\)|\1 -V|' build/Makefile
#make test -C build

%post -n lib%{name}%{soname} -p /sbin/ldconfig

%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_docdir}/%{name}
%{_bindir}/coNetperf
%{_bindir}/coNodeperf
%{_bindir}/coObjectperf
%exclude %{_docdir}/%{name}/API

%files -n lib%{name}%{soname}
%defattr(-,root,root)
%{_libdir}/libCollage.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/co
%{_libdir}/libCollage.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/API

%changelog
* Sat Sep 17 2016 avvissu@yandex.by
- Build with boost >= 1.60 (Collage-1.1.2_boost-1.60.patch)
* Sun May 17 2015 avvissu@yandex.ru
- Update to 1.1.2:
  * includes various bugfixes
- Add source package CMake-common (Common CMake modules)
- Drop old patches:
  * build_with_boost-1.56.patch
  * fix-64bit.diff
- Add new patches:
  * CMake_doxygen.patch
  * Collage-1.1.2_include.patch
* Sun May 10 2015 avvissu@yandex.ru
- Drop date-and-time.diff ((use echo (command))
* Fri May  8 2015 avvissu@yandex.ru
- Use pkgconfig in names of packages
- Drop sub_test.patch: use %%%%cmake
* Tue Dec 30 2014 avvissu@yandex.ru
- Fix build error with boost >= 1.56 (build_with_boost-1.56.patch)
* Wed Nov 12 2014 avvissu@yandex.ru
- Add support udt for ARM
* Sun Oct 26 2014 avvissu@yandex.ru
- Spec file cleanup
* Sun Oct 12 2014 avvissu@yandex.ru
- add OFED support on openSUSE > 13.1:
  * add RPM test suse_version
* Wed Sep 17 2014 avvissu@yandex.ru
- [Fixed] RPMlint W: Your file uses  __DATE and __TIME__ this
  causes the package to rebuild when not needed
* Wed Dec 25 2013 avvissu@yandex.ru
- add UDP-based Data Transfer Protocol
* Fri Dec 20 2013 avvissu@yandex.ru
- Initial release
